package com.goldenwater.slaj.eme.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eme.mapper.BusiInsureEvaMapper;
import com.goldenwater.slaj.eme.domain.BusiInsureEva;
import com.goldenwater.slaj.eme.service.IBusiInsureEvaService;

/**
 * 安全生产责任保险评估 服务层实现
 */
@Service
public class BusiInsureEvaServiceImpl implements IBusiInsureEvaService {

    @Autowired
    private BusiInsureEvaMapper busiInsureEvaMapper;

    @Override
    public BusiInsureEva selectBusiInsureEvaByGuid(String guid) {
        return busiInsureEvaMapper.selectBusiInsureEvaByGuid(guid);
    }

    @Override
    public List<BusiInsureEva> selectBusiInsureEvaList(BusiInsureEva busiInsureEva) {
        return busiInsureEvaMapper.selectBusiInsureEvaList(busiInsureEva);
    }

    @Override
    public int insertBusiInsureEva(BusiInsureEva busiInsureEva) {
        return busiInsureEvaMapper.insertBusiInsureEva(busiInsureEva);
    }

    @Override
    public int updateBusiInsureEva(BusiInsureEva busiInsureEva) {
        return busiInsureEvaMapper.updateBusiInsureEva(busiInsureEva);
    }

    @Override
    public int deleteBusiInsureEvaByGuid(String guid) {
        return busiInsureEvaMapper.deleteBusiInsureEvaByGuid(guid);
    }

    @Override
    public int deleteBusiInsureEvaByGuids(String[] guids) {
        return busiInsureEvaMapper.deleteBusiInsureEvaByGuids(guids);
    }
}
